# Navio-Integration
Python Module and Discord bot for Navio, the ETS2 job tracker.

> You can use the python Module [here](https://pypi.org/project/navio.py/)

## The Bot
Add drivers, remove drivers, view drivers, view jobs, setup webhooks, and much, much more. 
